=================================
education_math_homework_generator
=================================


.. image:: https://img.shields.io/pypi/v/education_math_homework_generator.svg
        :target: https://pypi.python.org/pypi/education_math_homework_generator

.. image:: https://img.shields.io/travis/physbean/education_math_homework_generator.svg
        :target: https://travis-ci.com/physbean/education_math_homework_generator

.. image:: https://pyup.io/repos/github/physbean/education_math_homework_generator/shield.svg
     :target: https://pyup.io/repos/github/physbean/education_math_homework_generator/
     :alt: Updates

.. image:: https://readthedocs.org/projects/education-math-homework-generator/badge/?version=latest
        :target: https://education-math-homework-generator.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/physbean/education_math_homework_generator/python-3-shield.svg
     :target: https://pyup.io/repos/github/physbean/education_math_homework_generator/
     :alt: Python 3


A repository of simple, scalable mathematics homework generator using python and latex to create pdfs for early childhood education.
Customizable tools are also included to be used as an aid, including custimizable number lines and tables. 
This project was started for self-learning on common distribution tools and utilities, but given the number of families now homeschooling their children because of SARS-CoV-2, this seemed like the most useful side project to put out their for the world. Any feedback or requests are welcome as I continue to learn project structure and all the other tools defined in this template (link below).


* Free software: MIT license
* Documentation: https://education-math-homework-generator.readthedocs.io.


Features
--------

* Generation of problems for learning addition, subtraction, and multiplication
* Tools to aid the student such as customizable number lines and tables.


Credits
-------

* SARS-CoV-2 


This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
